import request from '@/framework/utils/request';

export function keygroupList(params: any = {}) {
  return request({ url: '/sms/ac/keygroup/list', method: 'get', params });
}

export function abacusConfigList(params: any = {}) {
  return request({ url: '/sms/ac/abacusConfig/list', method: 'get', params });
}
export function saveAbacusConfig(data: any = {}) {
  return request({ headers: {'Content-Type': 'application/x-www-form-urlencoded'},url: '/sms/ac/abacusConfig', method: 'post', data });
}

export function abacusConfigItemList(params: any = {}) {
  return request({ url: '/sms/ac/abacusConfigItem/list', method: 'get', params });
}

export function deleteAbacusConfigItem(params: any = {}) {
  return request({ url: '/sms/ac/abacusConfigItem', method: 'delete', params });
}

export function saveAbacusConfigItem(data: any = {}) {
  return request({ url: '/sms/ac/abacusConfigItem', method: 'post', data });
}


